# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtsvg-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtsvg   %mklibname qt%{qtmajor}svg %{qtmajor}
%define libqtsvg_d %mklibname qt%{qtmajor}svg -d

Name:           qtsvg5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Svg component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtsvg
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Avoid-buffer-overflow-in-isSupportedSvgFeature.patch
Patch0002:      0002-Support-font-size-not-in-pixels.patch
Patch0003:      0003-Fix-text-x-y-when-the-length-is-not-in-pixels.patch
Patch0004:      0004-Improve-parsing-of-r.patch
Patch0005:      0005-SVG-Image-reading-Reject-oversize-svgs-as-corrupt.patch

#Branch Patchs

#Trunk Patchs

#Patch from Mageia
#
# Security patches
# P1000 -> ...

BuildRequires:  qtbase5-devel = %version

Provides:       qt%{qtmajor}-qtsvg = %{version}-%{release}

%description
The QtSvg module provides classes for displaying and creating SVG files.

%files
%{_qt5_plugindir}/iconengines/libqsvgicon.so
%{_qt5_plugindir}/imageformats/libqsvg.so

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtSvg%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtSvg%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtsvg.qch
%{_qt5_docdir}/qtsvg/
%endif

#------------------------------------------------------------------------------

%package -n %{libqtsvg}
Summary:        Qt%{qtmajor} Svg Component Library
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}
Provides:       libqt%{qtmajor}-qtsvg = %{version}-%{release}

%description -n %{libqtsvg}
Qt%{qtmajor} Svg Component Library.

The QtSvg module provides classes for displaying and creating SVG files.

%files -n %{libqtsvg}
%{_qt5_libdir}/libQt5Svg.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtsvg_d}
Summary:        Devel files needed to build apps based on QtSvg
Group:          Development/KDE and Qt
Requires:       %{libqtsvg} = %{version}
Provides:       libqtsvg5-devel = %{version}
Provides:       libqt5svg-devel = %{version}
Provides:       qtsvg5-devel = %{version}
Provides:       qt5svg-devel = %{version}

Provides:       libqtsvg5-private-devel = %{version}
Provides:       libqt5svg-private-devel = %{version}
Provides:       qtsvg5-private-devel = %{version}
Provides:       qt5svg-private-devel = %{version}

%description -n %{libqtsvg_d}
Devel files needed to build apps based on QtSvg.

%files -n %{libqtsvg_d}
%{_qt5_libdir}/libQt5Svg.prl
%{_qt5_libdir}/libQt5Svg.so
%{_qt5_libdir}/pkgconfig/Qt5Svg.pc
%{_qt5_libdir}/cmake/Qt5Svg/
%{_qt5_libdir}/cmake/Qt5Gui/Qt5Gui_QSvgIconPlugin.cmake
%{_qt5_libdir}/cmake/Qt5Gui/Qt5Gui_QSvgPlugin.cmake
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_svg.pri
%{_qt5_includedir}/QtSvg/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_svg_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtsvg-everywhere-src-%{qtversion}

rm -frv examples

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# Fix all buildroot paths
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L%{_builddir}/\S+,,g" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L%{_builddir}/?\S+,,g" {} \;

# Don't reference builddir neither /usr(/X11R6)?/ in .pc files.
perl -pi -e '\
s@-L/usr/X11R6/%{_lib} @@g;\
s@-I/usr/X11R6/include @@g;\
s@-L/%{_builddir}\S+@@g'\
    `find . -name \*.pc`

# .la and .a files, die, die, die.
find %{buildroot} -name '*.la' -delete


%changelog
* Sat Jan 18 2025 daviddavid <daviddavid> 5.15.16-1.mga10
+ Revision: 2139624
- New version 5.15.16
- add a virtual provides on libqt5-qtsvg

* Tue Jan 16 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2031617
- New version 5.15.12

* Mon May 22 2023 daviddavid <daviddavid> 5.15.7-2.mga9
+ Revision: 1957772
- backport upstream patch to fix CVE-2023-32573 (mga#31950)

* Mon Dec 05 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1918279
- New version 5.15.7

* Sat Sep 10 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1886282
- New version 5.15.6

* Sat Aug 27 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1881010
- New version 5.15.5

* Sun Apr 03 2022 umeabot <umeabot> 5.15.2-4.mga9
+ Revision: 1842480
- Mageia 9 Mass Rebuild

* Mon Jun 07 2021 daviddavid <daviddavid> 5.15.2-3.mga9
+ Revision: 1730027
- apply patch to really fix CVE-2021-3481 (mga#29014)
- add fedora patch to fix CVE-2021-3481 (mga#29014)

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652471
- New version 5.15.2

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624923
- New version 5.15.1

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589836
- New version 5.15.0
+ danf <danf>
- Switch URLs from http: to https:

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545438
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484759
- New version 5.14.1

* Sun Nov 10 2019 daviddavid <daviddavid> 5.13.1-2.mga8
+ Revision: 1459075
- move the plugins files from the lib subpkg to the main pkg

* Sun Sep 08 2019 neoclust <neoclust> 5.13.1-1.mga8
+ Revision: 1438503
- New version 5.13.1

* Sun Jul 14 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421100
- Rebuild against qt new locations

* Thu Jul 04 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1418145
- New version 5.13.0

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384550
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378549
- New version 5.12.2

* Fri Feb 01 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362294
- New version 5.12.1

* Sun Dec 09 2018 neoclust <neoclust> 5.12.0-1.mga7
+ Revision: 1339149
- New version 5.12.0

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319038
- New version 5.11.2

* Sun Sep 23 2018 umeabot <umeabot> 5.11.1-2.mga7
+ Revision: 1300730
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245824
- New version 5.11.1

* Fri May 25 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232123
- New version 5.11.0

* Mon Apr 09 2018 neoclust <neoclust> 5.10.1-1.mga7
+ Revision: 1216518
- New version 5.10.1

* Wed Feb 28 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1205686
- New version 5.9.4

* Mon Dec 18 2017 neoclust <neoclust> 5.9.3-1.mga7
+ Revision: 1183196
- New version 5.9.3

* Sun Jul 16 2017 neoclust <neoclust> 5.9.1-1.mga7
+ Revision: 1123582
- New version 5.9.1

* Thu Nov 03 2016 neoclust <neoclust> 5.6.2-1.mga6
+ Revision: 1064867
- New version 5.6.2

* Fri Sep 02 2016 daviddavid <daviddavid> 5.6.1-3.mga6
+ Revision: 1049792
- build missing docs part (mga#9812)
- add qtsvg5-doc subpackage

* Sun Jul 03 2016 neoclust <neoclust> 5.6.1-2.mga6
+ Revision: 1038382
- Update to version 5.6.1-1
- New version

* Wed May 11 2016 akien <akien> 5.6.0-2.mga6
+ Revision: 1013625
- Fix libname s/libqtsvg5/libqt5svg5/

* Thu Mar 17 2016 neoclust <neoclust> 5.6.0-1.mga6
+ Revision: 992499
+ rebuild (emptylog)

* Wed Mar 09 2016 neoclust <neoclust> 5.6.0-0.rc.2.mga6
+ Revision: 987853
- Rebuild Qt5 Stack to fix plasma crashes

* Sun Feb 28 2016 neoclust <neoclust> 5.6.0-0.rc.1.mga6
+ Revision: 980618
+ rebuild (emptylog)

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.4.mga6
+ Revision: 915975
- Rebuild against new cmake to have cmake() provides

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.3.mga6
+ Revision: 915753
- Rebuild against new cmake to have cmake() provides

* Mon Dec 21 2015 neoclust <neoclust> 5.6.0-0.beta.2.mga6
+ Revision: 912758
- Remove private devel packages

* Sat Dec 19 2015 neoclust <neoclust> 5.6.0-0.beta.1.mga6
+ Revision: 912205
- New version 5.6.0 Beta

* Tue Nov 10 2015 neoclust <neoclust> 5.5.1-2.mga6
+ Revision: 900370
- Rebuild against fixed qtbase5

* Fri Oct 23 2015 neoclust <neoclust> 5.5.1-1.mga6
+ Revision: 894503
- New version

* Sun Jul 12 2015 filipesaraiva <filipesaraiva> 5.5.0-1.mga6
+ Revision: 853387
- Update to Qt 5.5.0 version;
- Fix URL to new address qt.io;

* Tue Jun 23 2015 neoclust <neoclust> 5.5.0-0.rc.1.mga6
+ Revision: 839958
- New version 5.5 rc

* Fri Dec 12 2014 neoclust <neoclust> 5.4.0-1.mga5
+ Revision: 802763
- New version 5.4.0

* Sun Dec 07 2014 neoclust <neoclust> 5.3.2-1.mga5
+ Revision: 801814
- New version 5.3.2

* Wed Oct 15 2014 umeabot <umeabot> 5.3.1-3.mga5
+ Revision: 743691
- Second Mageia 5 Mass Rebuild

* Sun Oct 12 2014 umeabot <umeabot> 5.3.1-2.mga5
+ Revision: 738098
- Mageia 5 Mass Rebuild

* Thu Jun 26 2014 fwang <fwang> 5.3.1-1.mga5
+ Revision: 639814
- 5.3.1

* Tue May 20 2014 fwang <fwang> 5.3.0-1.mga5
+ Revision: 624062
- 5.3.0 final

* Fri May 09 2014 fwang <fwang> 5.3.0-0.rc.1.mga5
+ Revision: 621486
- update file list
- 5.3.0 rc

* Sun Apr 06 2014 fwang <fwang> 5.3.0-0.beta.1.mga5
+ Revision: 612347
- 5.3.0beta

* Mon Mar 03 2014 neoclust <neoclust> 5.3.0-0.alpha.1.mga5
+ Revision: 598915
- New version

* Thu Feb 06 2014 fwang <fwang> 5.2.1-1.mga5
+ Revision: 584237
- 5.2.1

* Sat Dec 14 2013 fwang <fwang> 5.2.0-2.mga4
+ Revision: 556706
- 5.2.0 final

* Sun Dec 01 2013 fwang <fwang> 5.2.0-1.rc1.1.mga4
+ Revision: 554446
- update file list
- 5.2.0 rc1

* Sat Oct 26 2013 fwang <fwang> 5.2.0-1.beta1.1.mga4
+ Revision: 547097
- 5.2.0 beta1

* Mon Oct 21 2013 umeabot <umeabot> 5.2.0-1.alpha.2.mga4
+ Revision: 538932
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 fwang <fwang> 5.2.0-1.alpha.1.mga4
+ Revision: 491138
- update file list
- 5.2.0 alpha1

* Mon May 27 2013 neoclust <neoclust> 5.2.0-0.0.20130523.2.mga4
+ Revision: 428824
- Rebuild against new qt5 libs location

* Sat May 25 2013 neoclust <neoclust> 5.2.0-0.0.20130523.1.mga4
+ Revision: 427078
- New QT 5.2 Snapshot

* Wed Apr 17 2013 neoclust <neoclust> 5.0.2-1.mga3
+ Revision: 410391
- New version 5.0.2

* Sat Feb 02 2013 neoclust <neoclust> 5.0.1-1.mga3
+ Revision: 393999
- New version 5.0.1 Final

* Wed Jan 30 2013 neoclust <neoclust> 5.0.1-0.rc1.2.mga3
+ Revision: 393557
- Slip private headers in its own subpackage

* Sat Jan 26 2013 neoclust <neoclust> 5.0.1-0.rc1.1.mga3
+ Revision: 392360
- New version 5.0.1 rc1
- Rebuild with new path
+ fwang <fwang>
- use xz

* Sun Jan 13 2013 umeabot <umeabot> 5.0.0-2.mga3
+ Revision: 380056
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 neoclust <neoclust> 5.0.0-1.mga3
+ Revision: 337516
- Qt 5.0.0 Final

* Sat Nov 17 2012 neoclust <neoclust> 5.0.0-0.beta.16.mga3
+ Revision: 319082
- imported package qtsvg5

